@@ -20,7 +20,7 @@ class OutputPushbullet(object):
 
       pushbullet:
         apikey: <API_KEY>
-        device: <DEVICE_IDEN> (can also be a list of device idens)
+        device: <DEVICE_IDEN> (can also be a list of device idens, or don't specify any idens to send to all devices)
         [title: <MESSAGE_TITLE>] (default: "{{task}} - Download started" -- accepts Jinja2)
         [body: <MESSAGE_BODY>] (default: "{{series_name}} {{series_id}}" -- accepts Jinja2)
 
@@ -31,7 +31,7 @@ class OutputPushbullet(object):
         from flexget import validator
         config = validator.factory("dict")
         config.accept("text", key="apikey", required=True)
-        config.accept("text", key="device", required=True)
+        config.accept("text", key="device", required=False)
         config.accept("list", key="device").accept("text")
         config.accept("text", key="title", required=False)
         config.accept("text", key="body", required=False)
@@ -47,7 +47,7 @@ class OutputPushbullet(object):
         config.setdefault("body", "{% if series_name is defined %}{{tvdb_series_name|d(series_name)}} "
                                      "{{series_id}} {{tvdb_ep_name|d('')}}{% elif imdb_name is defined %}{{imdb_name}} "
                                      "{{imdb_year}}{% else %}{{title}}{% endif %}")
-
+        config.setdefault("device", None)
         return config
 
     # Run last to make sure other outputs are successful before sending notification
@@ -68,7 +68,7 @@ class OutputPushbullet(object):
         client_headers["Authorization"] = "Basic %s" % base64.b64encode(apikey)
         
         if task.options.test:
-            log.info("Test mode.  Pushbullet configuration:")
+            log.info("Test mode. Pushbullet configuration:")
             log.info("    API_KEY: %s" % apikey)
             log.info("    Type: Note")
             log.info("    Device: %s" % device)
@@ -95,18 +95,20 @@ class OutputPushbullet(object):
 
             for device in devices:
                 # Build the request
-                data = {"device_iden": device, "type": "note", "title": title, "body": body}
+                if not device:
+                    data = {"type": "note", "title": title, "body": body}
+                else:
+                    data = {"device_iden": device, "type": "note", "title": title, "body": body}
 
                 # Check for test mode
                 if task.options.test:
-                    log.info("Test mode.  Pushbullet notification would be:")
+                    log.info("Test mode. Pushbullet notification would be:")
                     log.info("    Title: %s" % title)
                     log.info("    Body: %s" % body)
                     
                     # Test mode.  Skip remainder.
                     continue
 
-
                 # Make the request
                 response = task.requests.post(pushbullet_url, headers=client_headers, data=data, raise_status=False)
 
@@ -125,7 +127,6 @@ class OutputPushbullet(object):
                 else:
                     log.error("Unknown error when sending Pushbullet notification")
 
-
 @event('plugin.register')
 def register_plugin():
-    plugin.register(OutputPushbullet, "pushbullet", api_ver=2)
+    plugin.register(OutputPushbullet, "pushbullet", api_ver=2)
\ No newline at end of file
